pro csalogo,xpos,ypos,factor=fact,portrait=port,vertical=vert,color=color
;+
; NAME:  CSALOGO
; PURPOSE:
;      to draw an CSA logo on IDL plots for identification purposes.
; CATEGORY:
;      plotting,logo
; CALLING SEQUENCE:
;      CSALOGO,X_POS,Y_POS  [,FACTOR=number] [,/VERTICAL] [,/PORTRAIT]
; INPUTS:
;     X_POS - horizontal position of lower left corner in normal coordinates
;     Y_POS - vertical position of lower left corner in normal coordinates
; OPTIONAL INPUT PARAMETERS:
;     none
; KEYWORD PARAMETERS:
;     FACTOR - multiplication factor to control the size of the logo
;               Default = 0.1
;     VERTICAL - draws logo vertically
;     PORTRAIT - distorts logo so that it will look right when rotated
;                into portrait mode
;     COLOR - sets the color for the logo
; OUTPUTS:
;     none
; OPTIONAL OUTPUT PARAMETERS:
;     none
; COMMON BLOCKS:
;     none
; SIDE EFFECTS:
;     This program stores and reset the values of the system variables
;     it uses, but there may be side effects indirectly, so it is recommended
;     that this routine be used before or after the main plotting routines.
; RESTRICTIONS:
;     none
; PROCEDURE:
; MODIFICATION HISTORY:
;  Created by J. D. Trickey - 20-November-1991
;  added COLOR keyword - J. D. Trickey - 21-FEB-1992
;-
;
;
if keyword_set(fact) then factor=fact else factor=0.1
;
save_x=!x
save_y=!y
save_p=!p
;
!x.style=1+4
!y.style=1+4
!p.title=''
!p.subtitle=''
!x.title=''
!y.title=''
;
!p.noerase=1
;
if keyword_set(port) then rfact=0.763916 else rfact=1.0
if keyword_set(color) then !p.color=color
;
leaf1_x=[6.2,6.2,4.0,4.5,4.1,$
         6.4,6.4,6.7,6.7,6.2]
leaf1_y=[1.0,4.0,4.0,4.75,5.1,$
            6.8,4.0,4.0,1.0,1.0]
leaf2_x=[7.3,7.3,7.6,7.6,9.9,$
         9.5,10.0,7.8,7.8,7.3]
   leaf2_y=[1.0,4.0,4.0,6.8,5.1,$
            4.75,4.0,4.0,1.0,1.0]
leaf3_x=[7.0,3.3,1.7,$
        2.1,1.7,3.3,3.7,5.5,$
           4.9,5.9,7.0,8.1,9.1,$
           8.5,10.3,10.7,12.3,11.9,$
           12.3,10.7,7.0]
   leaf3_y=[8.7,5.7,6.8,$
           7.0,9.1,8.9,9.6,8.2,$
           11.5,11.0,13.0,11.0,11.5,$
           8.2,9.6,8.9,9.1,7.0,$
           6.8,5.7,8.7]
   cir_rad=fltarr(360)+0.5
   cir_ang=findgen(360)
   cir_x=cir_rad*cos(cir_ang/!radeg) +7.0
   cir_y=cir_rad*sin(cir_ang/!radeg) +7.5
   cir_x=[cir_x,cir_x(0)]
   cir_y=[cir_y,cir_y(0)]
   cir_y=cir_y*1.3
   leaf1_y=leaf1_y*1.3
   leaf2_y=leaf2_y*1.3
   leaf3_y=leaf3_y*1.3
   set_viewport,xpos,xpos+0.15*factor,ypos,ypos+0.15*factor
   !x.range=[0.,15.]
   !y.range=[0.,15.]
   plot,[0.],[0.]
   if keyword_set(vert) then begin
      polyfill,leaf1_y/rfact*(-1),leaf1_x*rfact
      polyfill,leaf2_y/rfact*(-1),leaf2_x*rfact
      polyfill,leaf3_y/rfact*(-1),leaf3_x*rfact
      polyfill,cir_y/rfact*(-1),cir_x*rfact
   endif else begin
      polyfill,leaf1_x/rfact,leaf1_y*rfact
      polyfill,leaf2_x/rfact,leaf2_y*rfact
      polyfill,leaf3_x/rfact,leaf3_y*rfact
      polyfill,cir_x/rfact,cir_y*rfact
   endelse
;
!p.noerase=0
;
!x=save_x
!y=save_y
!p=save_p
;
return
end
