PRO GET_TIME
;+
; NAME:  GET_TIME
; PURPOSE:  Convert CANOPUS TIME <--> CIVIL TIME on the fly
; CATEGORY: Utility
; CALLING SEQUENCE:  GET_TIME
; INPUTS:
;     Prompted for time, with a template given.
; OPTIONAL INPUT PARAMETERS:
;     yy[yy],mm,dd[/hh[,mi[,ss]]] OR yy[yy],ddd[/hh[,mi[,ss]]] OR CANOPUS_TIME
; KEYWORD PARAMETERS:   NONE
; OUTPUTS:  Result of the appropriate conversion
; OPTIONAL OUTPUT PARAMETERS: NONE
; COMMON BLOCKS:  NONE
; SIDE EFFECTS:   NONE
; RESTRICTIONS:   Only those that apply to CANOPUS TIME
; PROCEDURE:   Input is parsed to determine what it is, and appropriate conversion is done
;              using Wallis' FORTRAN CANOPUS_TIME.
; MODIFICATION HISTORY:
;        T.J.Hughes - HIA/NRCC - 90.12.11
;-

print,'Enter date and time:'
print,'yy[yy],mm,dd[/hh[,mi[,ss]]] OR yy[yy],ddd[/hh[,mi[,ss]]] OR CANOPUS_TIME'
dt=''
read,dt

err=0L
ctime=0L
hour=0L
min=0L
sec=0L
year=0l
month=0L
doy=0L
day=0L

;      +-------------------------------------------------------------------+
;      |If no "/", then either the time is defaulted to midnight, or       |
;      |CANOPUS_TIME has been entered. If latter, then there should be no  |
;      |"," in the string                                                  |
;      +-------------------------------------------------------------------+
ps=strpos(dt,'/')
time_ok=0
if ps eq -1 then begin
   test=strpos(dt,',')
   if test eq -1 then begin
      ctime=long(dt)
      goto, CIV_TIME
   endif else begin
      time_ok=1
      ps=strlen(strtrim(dt,2))
   endelse
endif

;      +-------------------------------------------------------------------+
;      |Parse out DATE                                                     |
;      +-------------------------------------------------------------------+
date=strmid(dt,0,ps)

len=strlen(date)
p1=strpos(date,',')
year=long(strmid(date,0,p1))
if year lt 100 then year=year+1900L

date=strmid(date,p1+1,len-p1-1)
len=strlen(date)
p1=strpos(date,',')

if p1 eq -1 then begin
   day=long(date)
endif else begin
   month=long(strmid(date,0,p1))
   day=long(strmid(date,p1+1,len-p1-1))
endelse

if time_ok eq 1 then goto,CAN_TIME

;      +-------------------------------------------------------------------+
;      |Parse out TIME                                                     |
;      +-------------------------------------------------------------------+
time=strmid(dt,ps+1,strlen(dt)-ps-1)
len=strlen(time)
p1=strpos(time,',')

if p1 eq -1 then begin
   hour=long(time)
endif else begin
   hour=long(strmid(time,0,p1))
   time=strmid(time,p1+1,len-p1-1)
   len=strlen(time)
   p1=strpos(time,',')

   if p1 eq -1 then begin
      min=long(time)
   endif else begin
      min=long(strmid(time,0,p1))
      sec=long(strmid(time,p1+1,len-p1-1))
   endelse
endelse

CAN_TIME:
canopus_time,year,month,day,hour,min,sec,ctime,err
if err ne 0 then begin
   print,'ERR from CANOPUS_TIME ',err
   return
endif

;      +-------------------------------------------------------------------+
;      |Call civil_time to get day_of_year                                 |
;      +-------------------------------------------------------------------+
CIV_TIME:
doy=0l
civil_time,year,month,day,doy,hour,min,sec,ctime
;if err ne 0 then begin
;   print,'ERR from CIVIL_TIME ',err
;   return
;endif

MSG:
print,' '
print,'$(1x,i4,''-'',a,''-'',a,'' ('',a,'') '',a,'':'',a,'':'',a,2x,i)',$
   year,formint(month,2),formint(day,2),formint(doy,2),formint(hour,2),formint(min,2),formint(sec,2),ctime
print,' '

return
END
