pro LINTRA,dir,GCLAT,GCLON,GCRKM,halt,pLAT,plon,pRKM,arc=arc
;+
; NAME:  LINTRA
; PURPOSE: field line tracing routine
; CATEGORY: MARIA
; CALLING SEQUENCE:
;      LINTRA,DIR,GCLAT,GCLON,GCRKM,HALT,PLAT,PLON,PRKM [,ARC=arc]
;
; INPUTS:
;      DIR - Controls direction of trace
;            +1 = up (toward higher alt.)
;            -1 = down
;      GCLAT - Geocentric latitude starting point  (deg)
;      GCLON - Geocentric longitude starting point (deg)
;      GCRKM - Geocentric radius starting point (km)
;      HALT  - Altitude above surface (geodetic) of destination (km)
; OPTIONAL INPUT PARAMETERS:
;      none
; KEYWORD PARAMETERS:
;      ARC   - Returns arc length of field line traced in km
; OUTPUTS:
;      PLAT - Geocentric latitude end point  (deg)
;      PLON - Geocentric longitude end point (deg)
;      PRKM - Geocentric radius end point (km)
; OPTIONAL OUTPUT PARAMETERS:
;      none
; COMMON BLOCKS:
;      none
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
; MODIFICATION HISTORY:
;     Written in IDL 2 - 30-April-1991 - J.D. Trickey
;-
;
if n_params(0) ne 8 then stop, $
   'LINTRA.PRO error: You must provide 8 parameters'
;
;      +-------------------------------------------------------------------+
;      |Define the logical needed to call LINTRA                           |
;      +-------------------------------------------------------------------+
if trnlog('Lintra_exe',logname) ne 1 then begin     
   setlog,'Lintra_exe', 'dan$:[trickey.wallis]lintra.EXE' 
endif
;
dirx=dir
gcla=gclat
gclo=gclon
gcrk=gcrkm
hal=halt
pla=0.0
plo=0.0
prk=0.0
arcx=0.0
;
istat=call_vms('LINTRA_EXE','lintra',dirx,gcla,gclo,gcrk,hal,$
                        pla,plo,prk,arcx)
;
plat=pla          
plon=plo  
prkm=prk
if keyword_set(arc) then arc=arcx
;  
return
end
