pro oplot_vect,x,y,x_vect,y_vect,z_vect,vect_scale,arrows,symsize=smsz,$
    noclip=nclp
;
;+
; NAME: Oplot_vect
; PURPOSE: To plot vectors on a pre-defined 2-D axis
; CATEGORY: Plotting
; CALLING SEQUENCE:
;   OPLOT_VECT,X,Y,X_VECT,Y_VECT,Z_VECT,VECT_SCALE,ARROWS
;   OPLOT_VECT,X,Y,X_VECT,Y_VECT,Z_VECT,VECT_SCALE,ARROWS,SYMSIZE=value
; INPUTS:
;   x,y                  - real array - coord's of vector bases 
;   x_vect,y_vect,z_vect - real array - elements of vectors (z is into page)
;   vect_scale           - real - vector scaling factor (length/max.value)
;   arrows               - integer - draw arrows flag (0=no arrows, 1=arrows)
; OPTIONAL INPUT PARAMETERS: None
; KEYWORD PARAMETERS: 
;   SYMSIZE - Factor used to control the size of the symbols plotted.
;             Default = 1.0
; OUTPUTS: None
; OPTIONAL OUTPUT PARAMETERS: None
; COMMON BLOCKS: None
; SIDE EFFECTS: None
; RESTRICTIONS: 
;   Not designed for the 3-d plotting available in IDL 2
; PROCEDURE:
;   The plot axis must be set (ex. uning a PLOT command) before using this
;   procedure
; MODIFICATION HISTORY:
;    Converted to IDL 2 - Dec. 1990 - J.D. Trickey
;    Added SYMSIZE keyword - Jan 1991 - J.D. Trickey
;    Added NOCLIP keyword - Aug 1993 - J.D. Trickey
;-
;
num=n_elements(x)
a=x(0)
b=y(0)
if keyword_set(smsz) then size=smsz else size=1.0
if keyword_set(nclp) then !p.noclip=1 
lintyp=!p.linestyle
psym=!p.psym
!p.linestyle=0
!p.psym=0
for i=0,num-1 do begin
   if arrows ge 1 then begin
      if y_vect(i) ne 0 then begin
          atan_th=atan(x_vect(i),y_vect(i))
          aa=[.1*sin(atan_th+10.*arrows/!radeg),$
              .1*sin(atan_th-10.*arrows/!radeg)]
          ba=[.1*cos(atan_th+10.*arrows/!radeg),$
              .1*cos(atan_th-10.*arrows/!radeg)]
      endif else begin
          if x_vect(i)-abs(x_vect(i)) eq 0 then sign=1 else sign=-1
          aa=[.1*sin((sign*90.+10.*arrows)/!radeg),$
              .1*sin((sign*90.-10.*arrows)/!radeg)]
          ba=[.1*cos((sign*90.+10.*arrows)/!radeg),$
              .1*cos((sign*90.-10.*arrows)/!radeg)]
      endelse
      a=[x(i),x(i)+x_vect(i)*vect_scale,x(i)+x_vect(i)*vect_scale-aa,$
         x(i)+x_vect(i)*vect_scale,x(i)]
      b=[y(i),y(i)+y_vect(i)*vect_scale,y(i)+y_vect(i)*vect_scale-ba,$
         y(i)+y_vect(i)*vect_scale,y(i)]
      oplot,a,b
   endif else begin
      a=[x(i),x(i)+x_vect(i)*vect_scale,x(i)]
      b=[y(i),y(i)+y_vect(i)*vect_scale,y(i)]
      oplot,a,b
   endelse
endfor
;
;
znum=n_elements(z_vect)
if znum gt 1 then begin
   iup=where(z_vect gt 0) 
   idown=where(z_vect lt 0) 
   izero=where(z_vect eq 0)
   if n_elements(iup) gt 1 then begin
      a=x(iup)
      b=y(iup)
   endif else begin
      if iup(0) ge 0 then begin
         a=[x(iup),x(iup)]
         b=[y(iup),y(iup)]
      endif
   endelse
   !p.psym=1
   if iup(0) ge 0 then oplot,a,b,symsize=size
   if n_elements(idown) gt 1 then begin
      a=x(idown)
      b=y(idown)
   endif else begin 
      if idown(0) ge 0 then begin
         a=[x(idown),x(idown)]
         b=[y(idown),y(idown)]
      endif
   endelse
   !p.psym=4
   if idown(0) ge 0 then oplot,a,b,symsize=size
   if n_elements(iZERO) gt 1 then begin
      a=x(iZERO)
      b=y(iZERO)
   endif else begin
      if izero(0) ge 0 then begin
         a=[x(iZERO),x(iZERO)]
         b=[y(iZERO),y(iZERO)]
      endif
   endelse
   !p.psym=2
   if izero(0) ge 0 then oplot,A,B,symsize=size
endif
;
!p.linestyle=lintyp
!p.psym=psym
!p.noclip=0
;
return
end
