PRO POLAR,A,B,LINTYP,SYM,A_VECT,B_VECT,Z_VECT,VECT_SCALE,NPLOT,NLINES,$
QUAD,ARROWS,SEGPLOT,DISPLAY,YEAR,DOY,MONTH,DAY,HOUR,MINUTE,SECOND,$
PLOT_TYPE,LABEL,datlab,baselab,orientation=orient,multi=m_num,$
plot_count=p_count
;
;+
; NAME: POLAR
; PURPOSE:
;     to plot data on polar axes
; CATEGORY:
; CALLING SEQUENCE:
;    POLAR,A,B,LINTYP,SYM,A_VECT,B_VECT,Z_VECT,VECT_SCALE,NPLOT,NLINES,$
;    QUAD,ARROWS,SEGPLOT,DISPLAY,YEAR,DOY,MONTH,DAY,HOUR,MINUTE,SECOND,$
;    PLOT_TYPE,LABEL,datlab,baselab$
;    [,orientation=orient] [,multi=m_num] [,plot_count=p_count]
; INPUTS:
;   A
;   B
;   LINTYP
;   sym        integer    - symbol to be used for plots with no z component
;   a_vect     real array - a component of vector
;   b_vect     real array - b component of vector
;   z_vect     real array - z component of vector
;   vect_scale real       - vector scale (ex. 1./(vector_max)  )
;   nplot      integer    - number of plot 1,2...nlines
;   nlines     integer    - total number of lines on the plot 
;   QUAD
;   arrows     real       - controls arrowheads on vectors
;                            0. = no arrowheads
;                            >0. = size of arrowhead
;   SEGPLOT    string     - whether or not to plot hard copy (segment)
;   DISPLAY    integer    - display control for hardcopy 
;                         1 = plot to screen as well as file
;                         0 = file output only, no screen
;                         -1 = postscript file
;   YEAR       integer    - Year of data
;   DOY        integer    - day of year of data
;   MONTH      integer    - month of data
;   DAY        integer    - day of month of data
;   HOUR       integer    - hour of data
;   MINUTE     integer    - minute of data
;   SECOND     integer    - second of data
;   PLOT_TYPE  integer    - indicates plot type
;                           1 = XYZ - Magnetoneter data
;                           2 = EXY - Telluric data
;                           3 = CUR - Equiv. Overhead Current
;   LABEL
;   DATLAB     string     - data type label (top right of plot)
;   baselab    string     - baseline label (bottom right of plot)                
;
; OPTIONAL INPUT PARAMETERS:
;     none
; KEYWORD PARAMETERS:
;    orientation=orient   integer    - orientation of postscript plot
;                                      0 = landscape [default]
;                                      1 = portrait
;                                      portrait may also be set by using
;                                      /orientation
;    multi=m_num          integer    - number of plots in multi setting
;    plot_count=p_count   integer    - plot count in multi setting
; OUTPUTS:
; OPTIONAL OUTPUT PARAMETERS:
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
; MODIFICATION HISTORY:
;-
;
COMMON POLAR_COM,this_term,x_scale,y_scale
;
COMMON FLAG,VSCALE_FLAG,ZV_FLAG
;
!quiet=1
SYM=LONG(SYM(0))
NPLOT=LONG(NPLOT(0))
LINTYP=LONG(LINTYP(0))
VECT_SCALE=FLOAT(VECT_SCALE(0))
if keyword_set(p_count) then begin
   p_count=long(p_count(0))
endif else begin
   p_count=0
endelse
if keyword_set(m_num) then begin
   m_num=long(m_num(0))
endif else begin
   m_num=1
endelse
if (!p.multi(1)*!p.multi(2) gt 0) then begin
   if (!p.multi(1) gt !p.multi(2)) then begin
      textsize=2./float(!p.multi(1))
   endif else begin
      textsize=2./float(!p.multi(2))
   endelse
endif else begin
   textsize=0.75
endelse
;
;
IF NPLOT EQ 1 THEN BEGIN
   if (p_count eq 1) then this_term=!d.name
   NLINES=LONG(NLINES(0))
   DISPLAY=FIX(DISPLAY(0))
   QUAD=LONG(QUAD(0))
   ARROWS=FLOAT(ARROWS(0))
   YEAR=LONG(YEAR(0))
   DOY=LONG(DOY(0))
   MONTH=LONG(MONTH(0))
   DAY=LONG(DAY(0))
   HOUR=LONG(HOUR(0))
   MINUTE=LONG(MINUTE(0))
   SECOND=LONG(SECOND(0))
   if keyword_set(orient) then begin
      orient=long(orient(0))
   endif else begin
      orient=0
   endelse
   !p.psym=0
   !p.linestyle=0
   VSCALE_FLAG=0
   ZV_FLAG=0
   if (p_count eq 1) and (segplot eq 'Y') then begin
     if display eq -1 then begin
        fname=string(year-1900)+string(month,'(i2.2)')+$
            string(day,'(i2.2)')+string(hour,'(i2.2)')+$
            string(minute,'(i2.2)')+string(second,'(i2.2)')+$
            '_POL_'+$
            strtrim(plot_type,2)+'.PS'
        print,'PostScript filename is: '+fname
        set_plot,'PS'
        if (orient eq 0) then begin
           device,/landscape,filename=fname
        endif else begin
           device,/portrait,filename=fname,ysize=25.7,xsize=20.25,$
             yoffset=0.75,xoffset=1.2
        endelse
     endif else begin 
        fname=string(year-1900)+string(month,'(i2.2)')+$
            string(day,'(i2.2)')+string(hour,'(i2.2)')+$
            string(minute,'(i2.2)')+string(second,'(i2.2)')+$
            '_POL_'+$
            strtrim(plot_type,2)+'.PLOT'
        print,'Plot filename is: '+fname
        if display eq 1 then begin
           print,'Note the name, and hit <CR> to continue ...'
           sjunk=''
           read,sjunk
        endif
        set_plot,'tek'
        openw,unit,fname+'/none',/get_lun
        if display eq 1 then begin
           device,/tek4014,plot_to=-1*unit
           print,string(27b)+string(12b)
        endif else begin
           device,/tek4014,plot_to=unit 
        endelse
     endelse
   endif
;
   al=intarr(361)
   for i=0,360 do al(i)=i
   !x.tickname=' '
   !y.tickname=' '
   !y.style=4
   !x.style=4
   !x.title=''
   !p.subtitle=''
   if (m_num eq 1) and (!p.multi(1)+!p.multi(0) le 0) then begin
      set_viewport,0.05,0.66,0.1,0.9
      !p.title=''
   endif else begin
      !p.position=[0.,0.,0.,0.]
      tl='Year:'+strtrim(string(year),2)+' Day:'+strtrim(string(doy,'(i3.3)'),2)$
      +'  '+strtrim(plot_type,2)
      bl='Time '+strtrim(string(year),2)+'/'+strtrim(string(month,'(i2.2)'),2)+'/'+$
      strtrim(string(day,'(i2.2)'),2)+' '+strtrim(string(hour,'(i2.2)'),2)+':'+$
      strtrim(string(minute,'(i2.2)'),2)+':'+strtrim(string(second,'(i2.2)'),2)+' UT'
      !p.title=tl+'  '+datlab
   endelse
   CASE QUAD OF 
     1: BEGIN
           !x.range=[0.0,8.0]
           !y.range=[0.0,8.0]
        END
     2: BEGIN
           !x.range=[-8.0,0.0]
           !y.range=[0.0,8.0]
        END
     3: BEGIN
           !x.range=[-8.0,0.0]
           !y.range=[-8.0,0.0]
        END
     4: BEGIN
           !x.range=[0.0,8.0]
           !y.range=[-8.0,0.0]
        END
     ELSE: BEGIN
           !x.range=[-8.0,8.0]
           !y.range=[-8.0,8.0]
           END
   ENDCASE
   plot,[0.0],[0.0]
;
   if (m_num gt 1) then begin
      x_dir=(!x.window(1)-!x.window(0))*!d.x_size
      y_dir=(!y.window(1)-!y.window(0))*!d.y_size
      if (x_dir gt y_dir) then begin
         y_scale=1.
         x_scale=y_dir/x_dir
      endif else begin
         x_scale=1.
         y_scale=x_dir/y_dir
      endelse
   endif else begin
      x_scale=1.
      y_scale=1.
   endelse
   CASE QUAD OF 
     1: BEGIN
           XYOUTS,8.2*x_scale,-0.2*y_scale,'0',size=textsize
           XYOUTS,-0.3*x_scale,8.2*y_scale,'90',size=textsize 
           XYOUTS,-0.3*x_scale,-8.4*y_scale,'270',size=textsize
           XYOUTS,-0.4*x_scale,2.0*y_scale,'80',size=textsize
           XYOUTS,-0.4*x_scale,4.0*y_scale,'70',size=textsize
           XYOUTS,-0.4*x_scale,6.0*y_scale,'60',size=textsize
           XYOUTS,-0.4*x_scale,8.0*y_scale,'50',size=textsize
        END
     2: BEGIN
           XYOUTS,-0.3*x_scale,8.2*y_scale,'90',size=textsize 
           XYOUTS,-9.*x_scale,-0.2*y_scale,'180',size=textsize
           XYOUTS,-0.3*x_scale,-8.4*y_scale,'270',size=textsize
           XYOUTS,0.1*x_scale,2.0*y_scale,'80',size=textsize
           XYOUTS,0.1*x_scale,4.0*y_scale,'70',size=textsize
           XYOUTS,0.1*x_scale,6.0*y_scale,'60',size=textsize
           XYOUTS,0.1*x_scale,8.0*y_scale,'50',size=textsize
        END
     3: BEGIN
           XYOUTS,-9.*x_scale,-0.2*y_scale,'180',size=textsize
           XYOUTS,-0.6*x_scale,-8.7*y_scale,'270',size=textsize
           XYOUTS,0.1*x_scale,-2.0*y_scale,'80',size=textsize
           XYOUTS,0.1*x_scale,-4.0*y_scale,'70',size=textsize
           XYOUTS,0.1*x_scale,-6.0*y_scale,'60',size=textsize
           XYOUTS,0.1*x_scale,-8.0*y_scale,'50',size=textsize
        END
     4: BEGIN
           XYOUTS,8.2*x_scale,-0.1*y_scale,'0',size=textsize
           XYOUTS,-0.3*x_scale,-8.4*y_scale,'270',size=textsize
           XYOUTS,-0.4*x_scale,-2.0*y_scale,'80',size=textsize
           XYOUTS,-0.4*x_scale,-4.0*y_scale,'70',size=textsize
           XYOUTS,-0.4*x_scale,-6.0*y_scale,'60',size=textsize
           XYOUTS,-0.4*x_scale,-8.0*y_scale,'50',size=textsize
        END
     ELSE: BEGIN
           XYOUTS,8.2*x_scale,-0.2*y_scale,'0',size=textsize
           XYOUTS,-0.3*x_scale,8.2*y_scale,'90',size=textsize 
           XYOUTS,-11.2*x_scale,-0.2*y_scale,'180',size=textsize
           XYOUTS,-0.6*x_scale,-10.7*y_scale,'270',size=textsize
           XYOUTS,2.2*x_scale,0.3*y_scale,'80',size=textsize
           XYOUTS,4.2*x_scale,0.3*y_scale,'70',size=textsize
           XYOUTS,6.2*x_scale,0.3*y_scale,'60',size=textsize
           XYOUTS,8.2*x_scale,0.3*y_scale,'50',size=textsize
           END
   ENDCASE
;
   if (m_num eq 1) and (!p.multi(1)+!p.multi(0) le 0) then begin
      xyouts,0.25,0.05,strtrim(LABEL,2),/normal,size=textsize
   endif else begin
      xyouts,2.5*x_scale,!y.crange(0)*y_scale,strtrim(LABEL,2)+'!C'+bl,size=textsize
      xyouts,0.2*x_scale,(!y.crange(0)-(1.2+!P.multi(2)/3)*textsize)*y_scale,$
         baselab,size=textsize
   endelse
   !p.NOERASe=1
   for I=1,4 do begin
       x=2*i*sin(al/!radeg)
       y=2*i*cos(al/!radeg)
       oplot,x*x_scale,y*y_scale
   endfor                    
   x=[-8.,8.]
   y=[0.,0.]
   oplot,x*x_scale,y*y_scale
   x=[0.,0.]
   y=[-8.,8.]
   oplot,x*x_scale,y*y_scale
   IF QUAD EQ 0 THEN BEGIN
      x=[8.*sin(210./!radeg),8.*sin(30./!radeg)]
      y=[8.*cos(210./!radeg),8.*cos(30./!radeg)]
      oplot,x*x_scale,y*y_scale
      x=[8.*sin(240./!radeg),8.*sin(60./!radeg)]
      y=[8.*COS(240./!radeg),8.*COS(60./!radeg)]
      oplot,x*x_scale,y*y_scale
      x=[8.*sin(300./!radeg),8.*sin(120./!radeg)]
      y=[8.*COS(300./!radeg),8.*COS(120./!radeg)]
      oplot,x*x_scale,y*y_scale
      x=[8.*sin(330./!radeg),8.*sin(150./!radeg)]
      y=[8.*COS(330./!radeg),8.*COS(150./!radeg)]
      oplot,x*x_scale,y*y_scale
   ENDIF ELSE IF (QUAD MOD 2) EQ 0 THEN BEGIN
         x=[8.*sin(300./!radeg),8.*sin(120./!radeg)]
         y=[8.*COS(300./!radeg),8.*COS(120./!radeg)]
         oplot,x*x_scale,y*y_scale
         x=[8.*sin(330./!radeg),8.*sin(150./!radeg)]
         y=[8.*COS(330./!radeg),8.*COS(150./!radeg)]
         oplot,x*x_scale,y*y_scale
      ENDIF ELSE BEGIN
         x=[8.*sin(210./!radeg),8.*sin(30./!radeg)]
         y=[8.*cos(210./!radeg),8.*cos(30./!radeg)]
         oplot,x*x_scale,y*y_scale
         x=[8.*sin(240./!radeg),8.*sin(60./!radeg)]
         y=[8.*COS(240./!radeg),8.*COS(60./!radeg)]
         oplot,x*x_scale,y*y_scale
      ENDELSE
ENDIF
;
;
IGOODA=WHERE(A LT 99990.)
x=(90.-a(IGOODA))/5.*cos((360.-b(IGOODA))/!radeg)
y=(A(IGOODA)-90.)/5.*sin((360.-b(IGOODA))/!radeg)
!p.LINEstyle=LINTYP
ZVNUM=N_ELEMENTS(Z_VECT)
IF ZVNUM LE 1 THEN BEGIN
     !p.PSYM=SYM
     oplot,x*x_scale,y*y_scale
ENDIF ELSE BEGIN
     ZV_FLAG=1
     !p.PSYM=0
ENDELSE
AVNUM=N_ELEMENTS(A_VECT)
IF AVNUM GT 1 THEN BEGIN
     IGOODV=WHERE((ABS(A_VECT) LT 99990.)and (ABS(B_VECT) LT 99990.))
     X_VECT=A_VECT(IGOODV)*(-1)*COS((b-360.)/!radeg)+$
            B_VECT(IGOODV)*SIN((360.-b)/!radeg)
     Y_VECT=A_VECT(IGOODV)*(-1)*SIN((b-360.)/!radeg)+$
            B_VECT(IGOODV)*COS((360.-b)/!radeg)
     IF ZVNUM LE 1 THEN BEGIN
        ZV=0.0
     ENDIF ELSE BEGIN
        ZV=z_vect(IGOODV)
     ENDELSE
     oplot_vect,x(IGOODV)*x_scale,y(IGOODV)*y_scale,$
                x_vect*x_scale,y_vect*y_scale,$
                ZV,vect_scale,ARROWS
     VSCALE_FLAG=1
ENDIF
!p.PSYM=0
;
IF NPLOT EQ NLINES THEN BEGIN
    !p.linestyle=0
;      +----------------------------------------------------------+
;      | Plot informational text                                  |
;      +----------------------------------------------------------+
    if (m_num eq 1) and (!p.multi(1)+!p.multi(0) le 0) then begin
       tl='Year:'+strtrim(string(year),2)+' Day:'+strtrim(string(doy,'(i3.3)'),2)+' '$
       +'  '+strtrim(plot_type,2)
       bl='Time '+strtrim(string(year),2)+'/'+strtrim(string(month,'(i2.2)'),2)+'/'+$
       strtrim(string(day,'(i2.2)'),2)+' '+strtrim(string(hour,'(i2.2)'),2)+':'+$
       strtrim(string(minute,'(i2.2)'),2)+':'+strtrim(string(second,'(i2.2)'),2)+' UT'
       headers,1,2,tl
       headers,2,2,datlab
       headers,3,2,baselab
       headers,1,1,bl
       time
       !X.TITLE=''
       IF VSCALE_FLAG EQ 1 THEN BEGIN
          !p.LINEstyle=0
          !p.PSYM=0
          set_viewport,0.75,.95,.1,.9
          !x.range=[0.0,0.0]
          !y.range=[0.0,0.0]
          IF QUAD EQ 0 THEN BEGIN
             Ybox=[20.,0.0,0.0,20.,20.]
             Xbox=[0.0,0.0,2.,2.,0.0]
          ENDIF ELSE BEGIN
             Ybox=[10.,0.0,0.0,10.,10.]
             Xbox=[0.0,0.0,2.,2.,0.0]
          ENDELSE
          plot,xbox,ybox
          X=[0.1,0.3,0.2,0.2,0.3,0.1]
          Y=[0.2,0.2,0.2,1.2,1.2,1.2]
          OPLOT,X,Y
          XYOUTS,0.3,0.6,STRTRIM(STRING(1./VECT_SCALE),2),size=textsize
          XYOUTS,0.2,1.4,'VECTOR SCALE',size=textsize
          IF ZV_FLAG EQ 1 THEN BEGIN
             IF QUAD GT 0 THEN BEGIN
                X=[0.5,0.5]
                Y=[2.3,2.3]
                !p.PSYM=1
                OPLOT,X,Y
                XYOUTS,0.7,2.2,'+VE',size=0.5
                Y=[2.0,2.0]
                !p.PSYM=4
                OPLOT,X,Y
                XYOUTS,0.7,1.9,'-VE',size=0.5
             ENDIF ELSE BEGIN
                X=[0.5,0.5]
                Y=[4.6,4.6]
                !p.PSYM=1
                OPLOT,X,Y
                XYOUTS,0.7,4.4,'+VE',size=0.5
                Y=[4.0,4.0]
                !p.PSYM=4
                OPLOT,X,Y
                XYOUTS,0.7,3.8,'-VE',size=0.5
             ENDELSE
          ENDIF
          !p.PSYM=0
       ENDIF
       csalogo,0.02,0.95,factor=0.25
    endif else begin
          IF VSCALE_FLAG EQ 1 THEN BEGIN
             !p.LINEstyle=0
             !p.PSYM=0
             X=[0.3,0.1,0.2,0.2,0.3,0.1]
             Y=[0.4,0.4,0.4,1.4,1.4,1.4]
             xt=0.5
             yt=0.8
             case quad of
               1: begin
                  x=x*(-1)+8.0
                  y=y*(-1)+8.0
                  xt=xt*(-1)+8.0
                  yt=yt*(-1)+8.0
                  t_ali=1.0
                  end 
               2: begin
                  x=x-8.0
                  y=y*(-1)+8.0
                  xt=-8.0
                  yt=yt*(-1)+8.0
                  t_ali=0.0
                  end 
               3: begin
                  x=x-8.0
                  y=y-8.0
                  xt=xt-8.0
                  yt=yt-8.0
                  t_ali=0.0
                  end
               4: begin
                  x=x*(-1)+8.0
                  y=y-8.0
                  xt=xt*(-1)+8.0
                  yt=yt-8.0
                  t_ali=1.0
                  end 
               else: begin
                     x=x-8.0
                     y=y-8.0
                     xt=xt-8.0
                     yt=yt-8.0
                     t_ali=0.0
                     end
             endcase
             OPLOT,X*x_scale,Y*y_scale
             XYOUTS,xt*x_scale,yt*y_scale,STRTRIM(STRING(1./VECT_SCALE),2),size=textsize,align=t_ali
;             XYOUTS,xt*x_scale,(yt+0.2)*y_scale,'VECTOR SCALE',size=textsize,align=t_ali
          ENDIF
    endelse
;
    if p_count ge m_num then begin
       !x.style=0
       !y.style=0
       !p.ticklen=0.02
       !x.tickname=''
       !y.tickname=''
       if (m_num gt 1) and (!p.multi(1)+!p.multi(0) le 0) then begin
          up=1
          time,up
          !p.title=''
          !p.subtitle=''
          if (orient eq 0) then begin
             csalogo,0.02,0.96,factor=0.25
          endif else begin
             csalogo,0.02,0.96,factor=0.25,/portrait
          endelse
       endif
       if segplot eq 'Y' then begin
          if display eq -1 then begin
            device,/close_file
            set_plot,this_term
            if (this_term eq 'X') then !p.color=0
         endif else begin
            device,plot_to=0
            close,unit
            set_plot,this_term
;            if display eq 1 then begin
;               print,string(7b)+'Hit <CR> to continue - Q to quit'
;               quit=''
;               read,quit
;            endif
            if this_term ne 'TEK' then begin
               print,string(27b)+'[?38l'
               print,string(27b)+'[?66h'
            endif else print,string(27b)+string(12b)
            !p.noerase=0
         endelse
      endif else begin
;            print,"$(1x,a1,'Hit <CR> to continue ...',$)",string(7b)
            quit=''
;            read,quit
      endelse
   endif                                                      
   !p.NOERASe=0
ENDIF
;
;
RETURN
END
;
