;+
; NAME:
;	CCF
; PURPOSE:
;	Return cross-correlation function.
;	The cross-correlation function is the normalized cross-covariance
;	function.
; CALLING SEQUENCE:
;	Result = CCF(X,Y)
; INPUTS:
;	X = Vector. First timeseries.
;	Y = Vector. Second timeseries.
; KEYWORD PARAMETERS:
;	MAXLAG = Absolute value of number of maximum lag for which ccf is
;		returned.
; OUTPUTS:
;	Result = vector of cross-correlation coefficients for
;		lags -MAXLAG, ..., -1, 0, 1, ..., MAXLAG. Result(i) is for
;		lag i-MAXLAG.
; PROCEDURE:
;	Calls IMSL_CCF.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 23 Jul 1991: Written in IDL2 by adapting CCV.
;	IFG, 4 Jan 1993: Added ON_ERROR.
;-

function ccf, x,y, maxlag=maxlag

on_error, 2
nobs = n_elements(x)
if nobs lt 1 then message, 'Error: X has too few elements'
if n_elements(y) ne nobs then $
   message, 'Error: X and Y must have same number of elements'
if not keyword_set(maxlag) then maxlag = nobs-1
if (maxlag lt 1) or (maxlag ge nobs) then $
   message, 'Error: Must have 1 <= MAXLAG < NOBS'

iprint = 0
iseopt = 0
imean = 1

imsl_ccf, nobs,x,y,maxlag,iprint,iseopt,imean,xmean,ymean,xvar,ccv1,cc,secc

return, cc

end
