;+
; NAME:
;	CCV
; PURPOSE:
;	Return cross-covariance function.
; CALLING SEQUENCE:
;	Result = CCV(X,Y)
; INPUTS:
;	X = vector. First timeseries.
;	Y = vector. Second timeseries.
; KEYWORD PARAMETERS:
;	MAXLAG = Absolute value of number of maximum lag for which ccv is
;		returned.
; OUTPUTS:
;	Result = vector of autocorrelation coefficients for
;		lags -MAXLAG, ..., -1, 0, 1, ..., MAXLAG. Result(i) is for
;		lag i-MAXLAG.
; PROCEDURE:
;	Calls IMSL_CCF.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRC, 18 Oct 1990: Written in IDL1.
;	IFG, 6 Feb 1991: Converted to IDL2.
;	IFG, 5 Mar 1991: Changed MAXLAG from parameter to keyword.
;	IFG, 23 Jul 1991: Changed text of MESSAGEs.
;	IFG, 4 Jan 1993: Added ON_ERROR.
;-

function ccv, x,y, maxlag=maxlag

on_error, 2
nobs = n_elements(x)
if nobs lt 1 then message, 'X has too few elements'
if n_elements(y) ne nobs then $
   message, 'X and Y must have same number of elements'
if not keyword_set(maxlag) then maxlag = nobs-1
if (maxlag lt 1) or (maxlag ge nobs) then $
   message, 'Must have 1 <= MAXLAG < NOBS'

iprint = 0
iseopt = 0
imean = 1

imsl_ccf, nobs,x,y,maxlag,iprint,iseopt,imean,xmean,ymean,xvar,ccv1,cc,secc

return, ccv1

end
