;+
; NAME:
;	GCGD
; PURPOSE:
;	Convert geocentric coordinates to geodetic.
; CALLING SEQUENCE:
;	GCGD, gclat, gcrkm, gdlat, gdalt
; INPUTS:
;	GCLAT = Geocentric latitude in radians.
;	GCRKM = Geocentric distance in km.
;	All inputs are FLOAT, and should be either all scalars or all vectors.
; OUTPUTS:
;	GDLAT = Geodetic latitude in radians.
;	GDALT = Altitude (geodetic) above MSL in km.
;	All outputs are FLOAT, and are scalars or vectors according to input.
; PROCEDURE:
;	Calls GCGD in FIELD.EXE.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 17 Feb 1992: Written in IDL2.
;       IFG 27 Jul 1992: Added ON_ERROR.
;-

pro gcgd, gclat, gcrkm, gdlat, gdalt

on_error, 2
if n_params(0) ne 4 then begin
   message, 'You must provide exactly 4 parameters.'
   return
   endif

if trnlog('FIELD$EXE',logname) ne 1 then $
   setlog, 'FIELD$EXE', 'UTL$IDL$DAN:FIELD.EXE'

n=n_elements(gclat)
gdlat=dblarr(n)
gdalt=gdlat
dl = 0.0
da = 0.0
la=float(gclat)
di=float(gcrkm)
for i=0,n-1 do begin
   status = call_external('field$exe', 'gcgd', la(i),di(i),dl,da)
   gdlat(i)=dl
   gdalt(i)=da
   endfor
if not isarray(gclat) then begin
   ; Scalars were input, so make output scalars
   gdlat = gdlat(0)
   gdalt = gdalt(0)
   endif
return
end
