;+
; NAME:
;	GDGC
; PURPOSE:
;	Convert geodetic coordinates to geocentric.
; CALLING SEQUENCE:
;	GDGC, gdlat, gdalt, gclat, gcrkm
; INPUTS:
;	GDLAT = Geodetic latitude in radians.
;	GDALT = Altitude (geodetic) above MSL in km.
;	All inputs are FLOAT, and should be either all scalars or all vectors.
; OUTPUTS:
;	GCLAT = Geocentric latitude in radians.
;	GCRKM = Geocentric distance in km.
;	All outputs are FLOAT, and are scalars or vectors according to input.
; PROCEDURE:
;	Calls GCGD in FIELD.EXE.
; MODIFICATION HISTORY:
;	Don Wallis, HIA/NRCC: Written in IDL1.
;	Ian Grant, 14 Feb 1992: Converted to IDL2.
;       IFG 27 Jul 1992: Added ON_ERROR.
;-

pro gdgc, gdlat, gdalt, gclat, gcrkm

on_error, 2
if n_params(0) ne 4 then begin
   message, 'You must provide exactly 4 parameters.'
   return
endif

if trnlog('FIELD$EXE',logname) ne 1 then $
   setlog, 'FIELD$EXE', 'UTL$IDL$DAN:FIELD.EXE'
n=n_elements(gdlat)
gclat=fltarr(n)
gcrkm=gclat
cl = 0.0
cd = 0.0
la=float(gdlat)
al=float(gdalt)
for i=0,n-1 do begin
   status = call_external('field$exe', 'gdgc', la(i),al(i),cl,cd)
   gclat(i)=cl
   gcrkm(i)=cd
   endfor
if not isarray(gdlat) then begin
   ; Scalars were input, so make output scalars
   gclat = gclat(0)
   gcrkm = gcrkm(0)
   endif
return
end
