;+
; NAME:
;	REGION_POSITION
; PURPOSE:
;	Set the default Plot Data Window relative to Plot Region (!P.REGION).
;	The Plot Region is defined by !P.REGION, or whole device area if 
;	!P.REGION is zero. 
;
;	On a scale such that the Plot Region extends over
;	(x0,y0,x1,y1) = (0,0,1,1), set !P.POSITION so that the Plot Data
;	Window extends over (x0,y0,x1,y1) = POS.
;
;	If no argument then reset !P.POSITION to 0.
; CALLING SEQUENCE:
;	REGION_POSITION, POS
; INPUTS:
;	pos = 4-element vector [x0,y0,x1,y1]. The coordinates of the corners
;	of the desired Plot Data Window on a scale such that the Plot Region
;	(!P.REGION) extends over (x0,y0,x1,y1) = (0,0,1,1).
; SIDE EFFECTS:
;	Sets !P.POSITION.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 1991, IDL2.
;	Ian Grant, UWO, 27 Sep 1993: Condensed code by using SUBRECT, PREGION.
;-

pro region_position, pos

if n_params() eq 0 then begin
   !p.position = 0
   return
   endif

!p.position = subrect(pregion(), pos, /to_abs)
return

end
