;+
; NAME:
;    SETMAP
; PURPOSE:
;    Set position of plot window within plot region with set X/Y scale ratio.
; CALLING SEQUENCE:
;    SETMAP, XRANGE=XRANGE, YRANGE=YRANGE
; KEYWORD PARAMETERS:
;    XLEN and YLEN are maximum lengths of axes.
;    ORIGIN is position of lower left corner.
;    ORIGIN=(x0,y0), XLEN and YLEN are in region coordinates, where region
;       coordinates run 0..1 across region, in both directions.
;    ASPECT_CELLXONY is Xlength/Ylength on the page (in, say, centimetres) of a
;       cell one X data unit by one Y data unit.
; SIDE EFFECTS:
;    Modifies !p.position.
; POSSIBILITIES FOR ENHANCEMENT:
;    - Centre grid in region if ORIGIN omitted.
;    - Choose default size and position if no parameters at all.
; MODIFICATION HISTORY:
;    Ian Grant, HIA/NRCC, 24 Apr 1992: Written in IDL2 by adapting BARS_SETGRID.
;-

pro setmap, xrange=xrange, yrange=yrange, origin=origin, xlen=xlen, ylen=ylen, $
   aspect_cellxony=aspect_cellxony

if (not keyword_set(xrange)) or (not keyword_set(yrange)) then $
   message, 'Must supply both XRANGE and YRANGE'
if not keyword_set(origin) then origin = [0.1,0.1]
if not keyword_set(xlen) then xlen = 0.95-origin(0)
if not keyword_set(ylen) then ylen = 0.95-origin(1)
if not keyword_set(aspect_cellxony) then aspect_cellxony = 1.0

dx = float(xrange(1)-xrange(0))
dy = float(yrange(1)-yrange(0))
aspect_maxarea = float(xlen) / ylen * aspect(/region)	; Aspect of max area
aspect_area = dx / dy * aspect_cellxony			; Desired aspect of plot
xlen2 = xlen
ylen2 = ylen
if aspect_area le aspect_maxarea then $
   xlen2 = ylen * aspect_cellxony * (dx / dy) / aspect(/region) $
else $
   ylen2 = xlen / aspect_cellxony / (dx / dy) * aspect(/region)

region_position, [ origin, origin+[xlen2,ylen2] ]

return
end
