;+
; NAME:
;	STRPOSLAST
; PURPOSE:
;	Return position of last occurrence of substring SUB in string EXP.
; CALLING SEQUENCE:
;	Result = STRPOSLAST( EXP, SUB )
; INPUTS:
;	EXP = scalar string to be searched.
;	SUB = scalar substring for which to search.
; OUTPUTS:
;	Result = Position in EXP at which last occurrence of SUB starts.
;	   First character is at position 0.
;	   Returns -1 if SUB is not a substring of EXP, or if EXP EQ ''.
;	   Returns one less than length of EXP if SUB EQ ''.
; RESTRICTIONS:
;	Scalars only.
; PROCEDURE:
;	Call STRPOS until no more occurrences found.
; MODIFICATION HISTORY:
;	Ian Grant, UWO, 26 Oct 1993: Written and tested.
;-

function strposlast, exp, sub

expstr = string(exp)
substr = string(sub)
if expstr eq '' then return, -1
if substr eq '' then return, strlen(expstr)-1

pos = -1
repeat begin
   prevpos = pos
   pos = strpos(expstr, substr, prevpos+1)
   endrep until pos eq -1

return, prevpos
end
