;+
; NAME:
;	WRAP_PREPLOT
; PURPOSE:
;	Prepare data for plotting, where data has circular scale, eg 360 degs.
;	At jumps, extra points are inserted (including a "missing" point), so
;	the plotted line extends across all x-values but does not join the ends
;	of the jump.
; CALLING SEQUENCE:
;	WRAP_PREPLOT, X, Y, MINVAL, MAXVAL, XOUT, YOUT, MISSING=MISSING
; INPUTS:
;	X = Vector of X-values (abscissae).
;	Y = Vector of Y-values (ordinates). Same length as X.
;	MINVAL = Start of allowed range of values for Y.
;	MAXVAL = End of allowed range of values for Y.
; KEYWORD PARAMETERS:
;	MISSING DEFAULT IS 99990.0.
; OUTPUTS:
;	XOUT = Vector of X values for plotting.
;	YOUT = Vector of Y values for plotting. Same length as XOUT.
; PROCEDURE:
;	Each jump between adjacent Y-values of greater than (MAXVAL-MINVAL)/2
;	is taken to be a jump across the ends of the Y range.
; MODIFICATION HISTORY:
;	Ian Grant, HIA/NRCC, 6 Mar 1992: Written in IDL2.
;-

pro wrap_preplot, x, y, minval, maxval, xout, yout, missing=missing

if not keyword_set(missing) then missing = 99999.0
range = maxval-minval
threshold = 0.5*range
yout = y
xout = x
i = 0
while i lt n_elements(yout)-1 do begin
   jump = yout(i+1) - yout(i)
   if abs(jump) gt threshold then begin
      sjump = sign(jump)
      yout = [ yout(0:i), $
               yout(i+1)-sjump*range, missing, yout(i)+sjump*range, $
               yout(i+1:*) ]
      xout = [ xout(0:i), $
               xout(i+1), xout(i), xout(i), $ ; Middle value is arbitrary
               xout(i+1:*) ]
      i = i+3
      endif
   i = i+1
   endwhile

return
end
