;+
; NAME:
;	X_CH_SIZE
; PURPOSE:
;	Return the X dimension of a character in DATA, DEVICE or NORMAL units.
; CALLING SEQUENCE:
;	Result = X_CH_SIZE( [/DEVICE] [/DATA] [/NORMAL] )
; INPUTS:
;	None.
; KEYWORD PARAMETERS:
;	DATA, DEVICE, NORMAL: At most one of these keywords may be present and
;	   nonzero. The default is DEVICE. The X size of a character in the
;	   selected coordinate system is returned.
; OUTPUTS:
;	Result = Float scalar. The character height in the selected coordinate
;	   system.
; PROCEDURE:
;	Converts the points (0, !D.X_CH_SIZE) and (0,0) to the requested
;	coordinate system and returns the difference between the X coordinates.
; MODIFICATION HISTORY:
;	Ian Grant, UWO, 22 Apr 1993: Written in IDL2, by modifying Y_CH_SIZE.
;-

function x_ch_size, device=device, data=data, normal=normal

on_error, 2
case howmany([keyword_set(device), keyword_set(data), keyword_set(normal)]) of
   0: device = !true
   1: dummy = 0
   else: message, 'More than one coordinate system selected'
   endcase

case !true of
   keyword_set(device): return, !d.x_ch_size
   keyword_set(data):   return, $
      ((convert_coord( !d.x_ch_size, 0, /device, /to_data))(0) - $
       (convert_coord( 0, 0,            /device, /to_data))(0))
   keyword_set(normal): return, $
      ((convert_coord( !d.x_ch_size, 0, /device, /to_normal))(0) - $
       (convert_coord( 0, 0,            /device, /to_normal))(0))
   endcase
end
