;+
; NAME:
;       PRO_HARDCOPY
; PURPOSE:
;       Offer hardcopy of graphics interactively.
; CALLING SEQUENCE:
;       PRO_HARDCOPY
;       Call once to open a plotfile and direct graphics to it.
;       Call again to close the plotfile and direct graphics back to the screen.
;       A typical interactive sequence is as follows.
;
;       IDL> plot, [1,2,3,4]            ; Plot graphics to screen (optional)
;       IDL> prohardcopy                ; Switch hardcopy on
;       Hardcopy on [P]ostscript, [L]J-250, p[C]l, or [N]one [n]: p     ; Select 'p'
;       IDL> plot, [1,2,3,4]            ; Send graphics to plotfile
;       IDL> prohardcopy                ; Switch off hardcopy
;       % HARDCOPY: Plot file is IDL.PS ; Message from HARDCOPY
;       IDL>
;
; INPUTS:
;       None.
; KEYWORDS:
;       PS: If present and nonzero, monochrome Postscript is selected as the
;          device.
;       LJ: If present and nonzero, LJ-250 is selected as the device.
;       PCL: if present and nonzero, printercommandlanguage output.
;       If neither PS nor LJ nor PCL is set, the routine prompts for a response.
;       FILENAME: String containing the name to be used for the plotfile.
;          Default is IDL.PS or IDL.LJ or IDL.PCL depending on the device.
; RESTRICTIONS:
;       It is intended that PROHARDCOPY only be called interactively. Use
;       HARDCOPY within programs.
;          Currently set up for hardcopy devices PostScript monochrome and
;       LJ-250 printer and pcl output.
; PROCEDURE:
;       Calls function HARDCOPY. See documentation of HARDCOPY for more details.
; MODIFICATION HISTORY:
;       Ian Grant, HIA/NRCC, 16 Aug 1991: Written in IDL2.
;       IFG, 23 Dec 1992: Added ON_ERROR.
;       IFG, 22 Jun 1993: Added keywords PS, LJ.
;       IFG, 26 Jan 1995: Added keyword FILENAME.
;       JWM, 31 Mar 1995: Added keyword PCL.
;       JWM, 4 Nov 1995: Added keyword PCN to produce narrow potrait orient plots.
;-

pro prohardcopy, ps= ps, lj = lj, pcl = pcl, pcn = pcn, filename = filename

on_error, 2
if not keyword_set(ps) then ps = !false
if not keyword_set(lj) then lj = !false
if not keyword_set(pcl) then pcl = !false
if not keyword_set(pcn) then pcn = !false
if not keyword_set(filename) then filename = ''
dummy = hardcopy(ps=ps, lj=lj, pcl=pcl, pcn = pcn, filename=filename)
return
end
